package
Version:
v0.2.1
Opens a new window with list of versions in this module.
Published: Jul 1, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GetKeys fetches the JWKS from the given URI using the provided HTTP client.
type Config struct {
Issuer string `json:"issuer"`
JWKsURI string `json:"jwks_uri"`
}
GetConfiguration fetches the OIDC configuration from the given URL using the provided HTTP client.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.