ports

package
v0.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 1, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Repo

type Repo interface {
	// Sites is an interface for managing sites.
	Sites
}

Repo is an interface for managing repositories.

type Sites

type Sites interface {
	// CreateSite creates a new site with the given name.
	CreateSite(ctx context.Context, name string) error
	// GetSite returns the site with the given name.
	GetSite(ctx context.Context, name string) (bool, error)
	// PutObject uploads a file to the S3 bucket with the given name.
	PutObject(ctx context.Context, site, name string, content []byte) error
	// DeleteObject deletes the object with the given name from the S3 bucket with the given name.
	DeleteObject(ctx context.Context, site, name string) error
}

Sites is an interface for managing sites. This interface wraps the S3 interface and provides additional site-specific functionality.

Jump to